<?php

namespace Controllers;

use Teknisa\Libs\Util\SMTP;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class TestConfigurationController extends \Zeedhi\Framework\Controller\Report
{
    protected $birtStrategy;
    protected $reportService;
    protected $QR2Strategy;
    protected $environment;

    public function __construct($reportService, $birtStrategy, $QR2Strategy, $environment)
    {
        $this->reportService     = $reportService;
        $this->birtStrategy      = $birtStrategy;
        $this->QR2Strategy       = $QR2Strategy;
        $this->environment       = $environment;
    }

    /** @var array */
    protected $reportMapping = array(
        'testConfiguration' =>
        array(
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array("NRORG" => "NRORG")
        ),
        'GER01300' =>
        array(
            'strategy' => 'QR2',
            'parameterMapping' =>
            array()
        )
    );

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        $qr2type = isset($row['QR2TYPE']) ? $row['QR2TYPE'] : 'PDF';
        $row['NRORG'] = $this->environment->getNrorgTrab();

        $this->birtStrategy->setReportFormat($qr2type);
        $this->QR2Strategy->setQr2Type($qr2type);
    }

    public function testConfiguration(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            if ($row['action'] == 'sendMail') {
                self::sendMail($row);
            } else {
                parent::createRemoteReport($request, $response);
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function sendMail($row)
    {

        $params = [
            "username" => $row["userLogin"],
            "password" => $row["passwordLogin"],
            "host" => $row["hostMail"],
            "port" => $row["portMail"],
            "smtpSecure" => $row["smtpSecure"],
            "smtpAuth" => $row["smtpAuth"],
        ];

        $address = $row['mailTo'];
        $message = 'TEST PHPMailer';

        $SMTP = new SMTP($params);

        $SMTP->sendMail('Teste', $address);
    }
}
